identify_METAR_token: Identify type of a METAR token

Description Usage Arguments Details Examples

View source: R/functions.R

Description

Determines the type of information conveyed by a particular METAR token.

Usage

1

Arguments

i

A string token, found separated by spaces in a METAR string. E.g. a METAR reading of METAR ZZZZ 010825Z 18010KT CAVOK 05/02 Q1000 NOSIG will have tokens "METAR", "ZZZZ", "010825Z", and etc.

Details

The METAR token i is distinguished via regular expression, and returns one of the following:

metar

Token METAR which usually occur at the start of a reading.

apt

Airport ICAO code.

time

Time information containing day, hour and minutes in Zulu/GMT.

wind

Wind information containing heading (degrees or VRB), wind speed, optional gusting wind speed and wind speed units (either knots KT, metres per second MPS or kilometres per hour KPH).

wind_vdir

Wind direction information containing two headings indicating range of varying wind direction.

vsby

Prevailing visibility in metres.

dvsby

Prevailing visibility in metres with directional indicator.

rvr

Runway visual range information containing runway, visibility range in metres and trend visual range change (increasing U, decreasing D or no change N).

wx

Weather code.

cloud

Cloud information containing amount (few FEW, scattered SCT, broken BKN or overcast OVC) and height of cloud base in hundreds of feet.

cloud_conv

Cloud information containing amount (few FEW, scattered SCT, broken BKN or overcast OVC), height of cloud base in hundreds of feet, and significant convective cloud (Cumulonimbus CB or Towering Cumulus TCU).

cloud_alt

Alternative cloud information such as "ceiling and visibility OK" CAVOK or no sigificant cloud NSC.

vv

Vertical visibility in hundreds of feet, this is found after a cloud token when sky is obscured.

tempdew

Air temperature and dew point in whole degrees Celsius.

qnh

QNH in millibar/hectopascal.

trend

Trend forecasts starting token, this is either becoming BECMG or temporary TEMPO. Note that time group tokens preceding the trend starting token cannot be recognised by identify_METAR_token

windshear

Wind shear starting token WS. Note that wind shear is currently unsupported.

unknown

When identify_METAR_token fails to recognise token argument.

Examples

1
2

derry-dev/metar documentation built on July 24, 2021, 8:39 a.m.