Description Usage Arguments Details Examples
Determines the type of information conveyed by a particular METAR token.
1 |
i |
A string token, found separated by spaces in a METAR string. E.g. a METAR reading of |
The METAR token i is distinguished via regular expression, and returns one of the following:
metarToken METAR which usually occur at the start of a reading.
aptAirport ICAO code.
timeTime information containing day, hour and minutes in Zulu/GMT.
windWind information containing heading (degrees or VRB), wind speed, optional gusting wind speed and wind speed units (either knots KT, metres per second MPS or kilometres per hour KPH).
wind_vdirWind direction information containing two headings indicating range of varying wind direction.
vsbyPrevailing visibility in metres.
dvsbyPrevailing visibility in metres with directional indicator.
rvrRunway visual range information containing runway, visibility range in metres and trend visual range change (increasing U, decreasing D or no change N).
wxWeather code.
cloudCloud information containing amount (few FEW, scattered SCT, broken BKN or overcast OVC) and height of cloud base in hundreds of feet.
cloud_convCloud information containing amount (few FEW, scattered SCT, broken BKN or overcast OVC), height of cloud base in hundreds of feet, and significant convective cloud (Cumulonimbus CB or Towering Cumulus TCU).
cloud_altAlternative cloud information such as "ceiling and visibility OK" CAVOK or no sigificant cloud NSC.
vvVertical visibility in hundreds of feet, this is found after a cloud token when sky is obscured.
tempdewAir temperature and dew point in whole degrees Celsius.
qnhQNH in millibar/hectopascal.
trendTrend forecasts starting token, this is either becoming BECMG or temporary TEMPO. Note that time group tokens preceding the trend starting token cannot be recognised by identify_METAR_token
windshearWind shear starting token WS. Note that wind shear is currently unsupported.
unknownWhen identify_METAR_token fails to recognise token argument.
1 2 | identify_METAR_token("18010KT")
identify_METAR_token("NOSIG")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.